@@ -17,7 +17,8 @@ self_fns={
 'file_out':'entry',
 'save_path':'entry',
 'audio_analog':'entry',
-'comps_to_show_arr':'value'
+'comps_to_show_arr':'value',
+'fluidsynthextracommand':'value'
 }
 
 octave_add_opts={
@@ -65,7 +66,7 @@ cmaps_opts=tuple(sorted(['viridis', 'plasma', 'inferno', 'magma', 'cividis',
 '''
 Google drive id for .sf2 files from https://sites.google.com/site/soundfonts4u/
 '''
-sound_font='17QuXRbApe0JTlYfBs7iSMCMu3xRWMHOV'
+sound_font='142L-FgN7ToWmiB2y7PzmcnGOvzGNnZX4'
 sound_presets={
 'Piano':0,
 'Piano w/ Reverb':1,
@@ -76,4 +77,4 @@ sound_presets={
 '''
 static variables
 '''
-fs=44100
\ No newline at end of file
+fs=44100
